% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sa_sb.R
\name{sa_sb}
\alias{sa_sb}
\title{Titration Curve for a Strong Acid}
\usage{
sa_sb(conc.acid = 0.1, conc.base = 0.1, pkw = 14, vol.acid = 50,
  plot = TRUE, eqpt = FALSE, overlay = FALSE, ...)
}
\arguments{
\item{conc.acid}{Molar concentration of the strong acid analyte;
defaults to 0.10 M.}

\item{conc.base}{Molar concentration of the strong base titrant;
defaults to 0.10 M.}

\item{pkw}{The pKw (or pKs) value for the solvent; defaults to water
as a solvent with a pKw of 14.}

\item{vol.acid}{Initial volume, in mL, of the solution that 
contains the strong acid analyte; defaults to 50.00 mL.}

\item{plot}{Logical; if TRUE, plots the titration curve.}

\item{eqpt}{Logical; if TRUE, draws a vertical line at the titration
curve's equivalence point.}

\item{overlay}{Logical; if TRUE, adds the current titration curve
to the existing titration curve.}

\item{\dots}{Additional arguments to pass to \code{plot()} function.}
}
\value{
A two-column data frame that contains the volume of titrant
in the first column and the solution's pH in the second column. Also
produces a plot of the titration curve with options to display the
equivalence point and to overlay titration curves.
}
\description{
This function calculates and plots the titration curve for a 
monoprotic strong acid analyte using a monoprotic strong base as 
the titrant. The calculation uses a single master equation
that finds the volume of titrant needed to achieve a fixed pH, 
as outlined in R. de Levie's \emph{Principles of Quantitative 
Chemical Analysis} (McGraw-Hill, 1997).
}
\examples{
### Simple titration curve with equivalence point
ex1 = sa_sb(eqpt = TRUE)
head(ex1)

### Overlay titration curves
sa_sb(conc.base = 0.10)
sa_sb(conc.base = 0.15, overlay = TRUE)
sa_sb(conc.base = 0.20, overlay = TRUE)
}
\author{
David T. Harvey, DePauw University. \email{harvey@depauw.edu}
}

